"""Example."""

UPPERCASE_SENTENCE = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
LOWERCASE_SENTENCE = "abcdefghijklmnopqrstuvwxyz"
INTEGER_SENTENCE = "0123456789"


def create_dict_and_invert(sentence):
    """Create a dictionary mapping each character to its index and the inverse.

    param sentence: string of characters to create the dictionary from
    return: a list containing the dictionary and its inverse
    """
    ret = {}
    for char in sentence:
        ret[char] = len(ret)
    inv_ret = {v: k for k, v in ret.items()}
    return [ret, inv_ret]


def cipher(char, move):
    """Cipher a character by moving it.

    param char: character to cipher
    param move: number of positions to move the character
    return: the ciphered character
    """
    [upper, inv_upper] = create_dict_and_invert(UPPERCASE_SENTENCE)
    [lower, inv_lower] = create_dict_and_invert(LOWERCASE_SENTENCE)
    [integers, inv_integers] = create_dict_and_invert(INTEGER_SENTENCE)

    if char in upper:
        newindex = (upper[char] + move) % 26
        return inv_upper[newindex]
    if char in lower:
        newindex = (lower[char] + move) % 26
        return inv_lower[newindex]
    if char in integers:
        newindex = (integers[char] + move) % 10
        return inv_integers[newindex]
    return char



"""Main script for the Pompey decipher application."""

import sys

from caesar_pompey.utils import cipher

# pragma: no cover


def main():
    """Implement main loop of pompey deciphering application."""
    sentence = sys.argv[1]
    ciphered = ""
    for char in sentence:
        ciphered = ciphered + str(cipher(char, -1))
    print(ciphered)


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['caesar_pompey']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['caesar = caesar_pompey.caesar:main',
                     'pompey = caesar_pompey.pompey:main']}

setup_kwargs = {
    'name': 'caesar-pompey',
    'version': '0.0.3',
    'description': 'Cipher and decipher message using caesar code.',
    'long_description': '# caesar_pompey\n\nCipher and deciper message using the Caesar algorithm.\n\n## Installation\n\n```bash\npoetry lock\npoetry install\n```\n',
    'author': 'Maxime Haselbauer',
    'author_email': 'maxime.haselbauer@googlemail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
}


setup(**setup_kwargs)
